@@ -191,22 +191,6 @@ AuthPlugin *auth_plugin_load(const char *pluginConfigPath)
 #endif
 
 
-#ifdef __SSLMITM
-//	if (plugname == "ssl") {
-#ifdef DGDEBUG
-//		std::cerr << "Enabling SSL login/core auth plugin" << std::endl;
-#endif
-//		return sslcorecreate(cv);
-//	}
-
-//	if (plugname == "core") {
-#ifdef DGDEBUG
-//		std::cerr << "Enabling SSL login/core auth plugin" << std::endl;
-#endif
-//		return sslcorecreate(cv);
-//	}
-#endif //__SSLMITM
-
     if (!is_daemonised) {
         std::cerr << thread_id << "Unable to load plugin: " << pluginConfigPath << std::endl;
     }
