@@ -16,6 +16,7 @@
 #include <exception>
 #include <netinet/in.h>
 #include <arpa/inet.h>
+#include <poll.h>
 
 int selectEINTR(int numfds, fd_set *readfds, fd_set *writefds, fd_set *exceptfds, struct timeval *timeout, bool honour_reloadconfig = false);
 
@@ -39,6 +40,17 @@ class BaseSocket
     void setTimeout(int t);
     // get timeout (is this actually used?)
     int getTimeout();
+    int getErrno();
+
+    bool isClosing();
+    bool isHup();
+    bool sockError();
+    bool isTimedout();
+    bool isNoOpp();
+    bool isNoRead();
+    bool isNoWrite();
+    bool isOpen();
+    bool ishup;
 
     // close & reset the connection - these must clear address structures & call baseReset/baseAccept
     virtual void reset() = 0;
@@ -47,17 +59,22 @@ class BaseSocket
     // non-blocking check for input data
     bool checkForInput();
     // blocking check for data, can be told to break on signal triggered config reloads (-r)
-    void checkForInput(int timeout, bool honour_reloadconfig = false) throw(std::exception);
+    bool bcheckSForInput(int timeout);
+    bool bcheckForInput(int timeout);
+    //void checkForInput(int timeout, bool honour_reloadconfig = false) throw(std::exception);
+   // void checkForInput(int timeout, bool honour_reloadconfig ) throw(std::exception);
     // non-blocking check for writable socket
     bool readyForOutput();
     // blocking check, can break on config reloads
-    void readyForOutput(int timeout, bool honour_reloadconfig = false) throw(std::exception);
+    bool breadyForOutput(int timeout);
+    //void readyForOutput(int timeout, bool honour_reloadconfig = false) throw(std::exception);
+    //void readyForOutput(int timeout, bool honour_reloadconfig ) throw(std::exception);
 
     // get a line from the socket - can break on config reloads
-    int getLine(char *buff, int size, int timeout, bool honour_reloadconfig = false, bool *chopped = NULL, bool *truncated = NULL) throw(std::exception);
+    int getLine(char *buff, int size, int timeout, bool honour_reloadconfig = false, bool *chopped = NULL, bool *truncated = NULL);
 
     // write buffer to string - throws std::exception on error
-    void writeString(const char *line) throw(std::exception);
+    bool writeString(const char *line); //throw(std::exception);
     // write buffer to string - can be told not to do an initial readyForOutput, and told to break on -r
     bool writeToSocket(const char *buff, int len, unsigned int flags, int timeout, bool check_first = true, bool honour_reloadconfig = false);
     // read from socket, returning number of bytes read
@@ -65,19 +82,28 @@ class BaseSocket
     // read from socket, returning error status - can be told to skip initial checkForInput, and to break on -r
     int readFromSocket(char *buff, int len, unsigned int flags, int timeout, bool check_first = true, bool honour_reloadconfig = false);
     // write to socket, throwing std::exception on error - can be told to break on -r
-    void writeToSockete(const char *buff, int len, unsigned int flags, int timeout, bool honour_reloadconfig = false) throw(std::exception);
+  //  void writeToSockete(const char *buff, int len, unsigned int flags, int timeout, bool honour_reloadconfig = false) throw(std::exception);
+    void writeToSockete(const char *buff, int len, unsigned int flags, int timeout, bool honour_reloadconfig = false);
 
     protected:
-    // socket-wide timeout (is this actually used?)
+    // socket-wide timeout
     int timeout;
+    int s_errno;
     // length of address of other end of socket (e.g. size of sockaddr_in or sockaddr_un)
     socklen_t peer_adr_length;
     // socket FD
     int sck;
+    bool isclosing;
+    //bool ishup;
+    bool sockerr;
+    bool timedout;
     // internal buffer
-    char buffer[1024];
+    //char buffer[1024];
+    char buffer[4096];
     int buffstart;
     int bufflen;
+    struct pollfd infds[1];
+    struct pollfd outfds[1];
 
     // constructor - sets default values. override this if you actually wish to create a default socket.
     BaseSocket();
