@@ -10,7 +10,9 @@
 #ifdef HAVE_CONFIG_H
 #include "dgconfig.h"
 #endif
+#include <deque>
 #include "String.hpp"
+#include "HTTPHeader.hpp"
 #include "NaughtyFilter.hpp"
 #include "ContentScanner.hpp"
 #include "ConfigVar.hpp"
@@ -28,6 +30,7 @@
 // GLOBALS
 extern bool is_daemonised;
 extern OptionContainer o;
+extern thread_local std::string thread_id;
 
 // find the class factory functions for the CS plugins we've been configured to build
 
@@ -82,16 +85,16 @@ int CSPlugin::makeTempFile(String *filename)
 {
     int tempfilefd;
     String tempfilepath(o.download_dir.c_str());
-    tempfilepath += "/tfXXXXXX";
+    tempfilepath += "/csXXXXXX";
     char *tempfilepatharray = new char[tempfilepath.length() + 1];
     strcpy(tempfilepatharray, tempfilepath.toCharArray());
     //	mode_t mask = umask(S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP); // this mask is reversed
     umask(0007); // only allow access to e2g user and group
     if ((tempfilefd = mkstemp(tempfilepatharray)) < 1) {
 #ifdef DGDEBUG
-        std::cerr << "error creating cs temp " << tempfilepath << ": " << strerror(errno) << std::endl;
+        std::cerr << thread_id << "error creating cs temp " << tempfilepath << ": " << strerror(errno) << std::endl;
 #endif
-        syslog(LOG_ERR, "%s", "Could not create cs temp file.");
+        syslog(LOG_ERR, "%s%s", thread_id.c_str(), "Could not create cs temp file.");
         tempfilefd = -1;
     } else {
         (*filename) = tempfilepatharray;
@@ -107,14 +110,14 @@ int CSPlugin::writeMemoryTempFile(const char *object, unsigned int objectsize, S
     int tempfd = makeTempFile(filename); // String gets modified
     if (tempfd < 0) {
 #ifdef DGDEBUG
-        std::cerr << "Error creating temp file in writeMemoryTempFile." << std::endl;
+        std::cerr << thread_id << "Error creating temp file in writeMemoryTempFile." << std::endl;
 #endif
-        syslog(LOG_ERR, "%s", "Error creating temp file in writeMemoryTempFile.");
+        syslog(LOG_ERR, "%s%s", thread_id.c_str(), "Error creating temp file in writeMemoryTempFile.");
         return DGCS_ERROR;
     }
     errno = 0;
 #ifdef DGDEBUG
-    std::cout << "About to writeMemoryTempFile " << (*filename) << " size: " << objectsize << std::endl;
+    std::cerr << thread_id << "About to writeMemoryTempFile " << (*filename) << " size: " << objectsize << std::endl;
 #endif
 
     while (true) {
@@ -140,9 +143,9 @@ int CSPlugin::scanMemory(HTTPHeader *requestheader, HTTPHeader *docheader, const
     String tempfilepath;
     if (writeMemoryTempFile(object, objectsize, &tempfilepath) != DGCS_OK) {
 #ifdef DGDEBUG
-        std::cerr << "Error creating/writing temp file for scanMemory." << std::endl;
+        std::cerr << thread_id << "Error creating/writing temp file for scanMemory." << std::endl;
 #endif
-        syslog(LOG_ERR, "%s", "Error creating/writing temp file for scanMemory.");
+        syslog(LOG_ERR, "%s%s", thread_id.c_str(), "Error creating/writing temp file for scanMemory.");
         return DGCS_SCANERROR;
     }
     int rc = scanFile(requestheader, docheader, user, foc, ip, tempfilepath.toCharArray(), checkme, disposition, mimetype);
@@ -153,45 +156,49 @@ int CSPlugin::scanMemory(HTTPHeader *requestheader, HTTPHeader *docheader, const
 }
 
 // read in all the lists of various things we do not wish to scan
-bool CSPlugin::readStandardLists()
+bool CSPlugin::readStandardLists()      // this is now done in Storyboard
 {
+    return true;
+
+#ifdef NOTDEF
     exceptionvirusmimetypelist.reset(); // incase this is a reload
     exceptionvirusextensionlist.reset();
     exceptionvirussitelist.reset();
     exceptionvirusurllist.reset();
     if (!exceptionvirusmimetypelist.readItemList(cv["exceptionvirusmimetypelist"].toCharArray(), false, 0)) {
         if (!is_daemonised) {
-            std::cerr << "Error opening exceptionvirusmimetypelist" << std::endl;
+            std::cerr << thread_id << "Error opening exceptionvirusmimetypelist" << std::endl;
         }
-        syslog(LOG_ERR, "%s", "Error opening exceptionvirusmimetypelist");
+        syslog(LOG_ERR, "%s%s", thread_id.c_str(), "Error opening exceptionvirusmimetypelist");
         return false;
     }
     exceptionvirusmimetypelist.doSort(false);
     if (!exceptionvirusextensionlist.readItemList(cv["exceptionvirusextensionlist"].toCharArray(), false, 0)) {
         if (!is_daemonised) {
-            std::cerr << "Error opening exceptionvirusextensionlist" << std::endl;
+            std::cerr << thread_id << "Error opening exceptionvirusextensionlist" << std::endl;
         }
-        syslog(LOG_ERR, "%s", "Error opening exceptionvirusextensionlist");
+        syslog(LOG_ERR, "%s%s", thread_id.c_str(), "Error opening exceptionvirusextensionlist");
         return false;
     }
     exceptionvirusextensionlist.doSort(false);
     if (!exceptionvirussitelist.readItemList(cv["exceptionvirussitelist"].toCharArray(), false, 0)) {
         if (!is_daemonised) {
-            std::cerr << "Error opening exceptionvirussitelist" << std::endl;
+            std::cerr << thread_id << "Error opening exceptionvirussitelist" << std::endl;
         }
-        syslog(LOG_ERR, "%s", "Error opening exceptionvirussitelist");
+        syslog(LOG_ERR, "%s%s", thread_id.c_str(), "Error opening exceptionvirussitelist");
         return false;
     }
     exceptionvirussitelist.doSort(false);
     if (!exceptionvirusurllist.readItemList(cv["exceptionvirusurllist"].toCharArray(), true, 0)) {
         if (!is_daemonised) {
-            std::cerr << "Error opening exceptionvirusurllist" << std::endl;
+            std::cerr << thread_id << "Error opening exceptionvirusurllist" << std::endl;
         }
-        syslog(LOG_ERR, "%s", "Error opening exceptionvirusurllist");
+        syslog(LOG_ERR, "%s%s", thread_id.c_str(), "Error opening exceptionvirusurllist");
         return false;
     }
     exceptionvirusurllist.doSort(true);
     return true;
+#endif
 }
 
 // Test whether or not a particular request's incoming/outgoing data should be scanned.
@@ -203,7 +210,7 @@ int CSPlugin::willScanRequest(const String &url, const char *user, FOptionContai
     // Most content scanners only deal with original, unmodified content
     if (reconstituted) {
 #ifdef DGDEBUG
-        std::cout << "willScanRequest: ignoring reconstituted data" << std::endl;
+        std::cerr << thread_id << "willScanRequest: ignoring reconstituted data" << std::endl;
 #endif
         return DGCS_NOSCAN;
     }
@@ -214,17 +221,24 @@ int CSPlugin::willScanRequest(const String &url, const char *user, FOptionContai
     if (post) {
         if (scanpost) {
 #ifdef DGDEBUG
-            std::cout << "willScanRequest: I'm interested in uploads" << std::endl;
+            std::cerr << thread_id << "willScanRequest: I'm interested in uploads" << std::endl;
 #endif
             return DGCS_NEEDSCAN;
         } else {
 #ifdef DGDEBUG
-            std::cout << "willScanRequest: Not interested in uploads" << std::endl;
+            std::cerr << thread_id << "willScanRequest: Not interested in uploads" << std::endl;
 #endif
             return DGCS_NOSCAN;
         }
     }
 
+
+   // all list checkng is now done in Storyboard request
+    // and filetype checking in Storyboard response
+    //
+    return DGCS_NEEDSCAN;
+
+#ifdef NOTDEF
     String urld(HTTPHeader::decode(url));
     String lc;
     urld.removeWhiteSpace();
@@ -245,7 +259,7 @@ int CSPlugin::willScanRequest(const String &url, const char *user, FOptionContai
     if (((foc->reporting_level == 1) || (foc->reporting_level == 2))
         && domain.startsWith(foc->access_denied_domain)) {
 #ifdef DGDEBUG
-        std::cout << "willScanRequest: ignoring our own webserver" << std::endl;
+        std::cerr << thread_id << "willScanRequest: ignoring our own webserver" << std::endl;
 #endif
         return DGCS_NOSCAN;
     }
@@ -255,7 +269,7 @@ int CSPlugin::willScanRequest(const String &url, const char *user, FOptionContai
     while (tempurl.contains(".")) {
         if (exceptionvirussitelist.findInList(tempurl.toCharArray(), lc) != NULL) {
 #ifdef DGDEBUG
-            std::cout << "willScanRequest: ignoring exception virus site" << std::endl;
+            std::cerr << thread_id << "willScanRequest: ignoring exception virus site" << std::endl;
 #endif
             return DGCS_NOSCAN; // exact match
         }
@@ -266,7 +280,7 @@ int CSPlugin::willScanRequest(const String &url, const char *user, FOptionContai
         tempurl = "." + tempurl;
         if (exceptionvirussitelist.findInList(tempurl.toCharArray(), lc) != NULL) {
 #ifdef DGDEBUG
-            std::cout << "willScanRequest: ignoring exception virus site" << std::endl;
+            std::cerr << thread_id << "willScanRequest: ignoring exception virus site" << std::endl;
 #endif
             return DGCS_NOSCAN; // exact match
         }
@@ -286,13 +300,13 @@ int CSPlugin::willScanRequest(const String &url, const char *user, FOptionContai
                 unsigned char c = tempurl[fl];
                 if (c == '/' || c == '?' || c == '&' || c == '=') {
 #ifdef DGDEBUG
-                    std::cout << "willScanRequest: ignoring exception virus URL" << std::endl;
+                    std::cerr << thread_id << "willScanRequest: ignoring exception virus URL" << std::endl;
 #endif
                     return DGCS_NOSCAN; // matches /blah/ or /blah/foo but not /blahfoo
                 }
             } else {
 #ifdef DGDEBUG
-                std::cout << "willScanRequest: ignoring exception virus URL" << std::endl;
+                std::cerr << thread_id << "willScanRequest: ignoring exception virus URL" << std::endl;
 #endif
                 return DGCS_NOSCAN; // exact match
             }
@@ -301,96 +315,22 @@ int CSPlugin::willScanRequest(const String &url, const char *user, FOptionContai
     }
 
 #ifdef DGDEBUG
-    std::cout << "willScanRequest: I'm interested" << std::endl;
+    std::cerr << thread_id << "willScanRequest: I'm interested" << std::endl;
 #endif
     return DGCS_NEEDSCAN;
+#endif
 }
 
 // Test whether or not a particular request's incoming/outgoing data should be scanned.
 // This is a later-stage test; info is known about the actual data itself when this is called.
 int CSPlugin::willScanData(const String &url, const char *user, FOptionContainer* &foc, const char *ip, bool post,
     bool reconstituted, bool exception, bool bypass, const String &disposition, const String &mimetype,
-    off_t size)
-{
-    String lc;
-    //exceptionvirusmimetypelist
-    if (mimetype.length() > 2) {
-        if (exceptionvirusmimetypelist.findInList(mimetype.toCharArray(), lc) != NULL) {
-#ifdef DGDEBUG
-            std::cout << "willScanData: ignoring exception MIME type (" << mimetype.c_str() << ")" << std::endl;
-#endif
-            return DGCS_NOSCAN; // match
-        }
-    }
-
-    //exceptionvirusextensionlist
-    String extension;
-    if (disposition.length() > 2) {
-// If we have a content-disposition, determine file extension from that
-#ifdef DGDEBUG
-        std::cout << "disposition: " << disposition << std::endl;
-#endif
-        std::string::size_type start = disposition.find("filename=");
-        if (start != std::string::npos) {
-            start += 9;
-            char endchar = ';';
-            if (disposition[start] == '"') {
-                endchar = '"';
-                ++start;
-            }
-            std::string::size_type end = disposition.find(endchar, start);
-            if (end != std::string::npos)
-                extension = disposition.substr(start, end - start);
-            else
-                extension = disposition.substr(start);
-        }
-        while (extension.contains(".")) {
-            extension = extension.after(".");
-        }
-        extension = "." + extension;
-#ifdef DGDEBUG
-        std::cout << "extension from disposition: " << extension << std::endl;
-#endif
-    } else {
-        // Otherwise, determine it from the URL
-        String urld(HTTPHeader::decode(url)), path;
-        urld.removeWhiteSpace();
-        urld.toLower();
-        urld.removePTP();
-
-        if (urld.contains("/")) {
-            path = urld.after("/");
-            path.hexDecode();
-            path.realPath();
-        }
-
-        if (!path.contains("?")) {
-            extension = path;
-        } else if (mimetype.contains("application/")) {
-            extension = path;
-            if (extension.contains("?")) {
-                extension = extension.before("?");
-            }
-        }
-#ifdef DGDEBUG
-        std::cout << "extension from URL: " << extension << std::endl;
-#endif
-    }
-    if (extension.contains(".")) {
-        if (exceptionvirusextensionlist.findEndsWith(extension.toCharArray(), lc) != NULL) {
-#ifdef DGDEBUG
-            std::cout << "willScanData: ignoring exception file extension (" << extension.c_str() << ")" << std::endl;
-#endif
-            return DGCS_NOSCAN; // match
-        }
-    }
-
-#ifdef DGDEBUG
-    std::cout << "willScanData: I'm interested" << std::endl;
-#endif
-    return DGCS_NEEDSCAN;
+    off_t size) {
+    // this function is no longer required as mime/extension exceptions are now handled by Storyboard response
+    return DGCS_NEEDSCAN; // match
 }
 
+
 //set the blocking information
 void CSPlugin::blockFile(std::string *_category, std::string *_message, NaughtyFilter *checkme)
 {
@@ -427,25 +367,25 @@ CSPlugin *cs_plugin_load(const char *pluginConfigPath)
 
     if (cv.readVar(pluginConfigPath, "=") > 0) {
         if (!is_daemonised) {
-            std::cerr << "Unable to load plugin config: " << pluginConfigPath << std::endl;
+            std::cerr << thread_id << "Unable to load plugin config: " << pluginConfigPath << std::endl;
         }
-        syslog(LOG_ERR, "Unable to load plugin config %s", pluginConfigPath);
+        syslog(LOG_ERR, "%sUnable to load plugin config %s",thread_id.c_str(),  pluginConfigPath);
         return NULL;
     }
 
     String plugname(cv["plugname"]);
     if (plugname.length() < 1) {
         if (!is_daemonised) {
-            std::cerr << "Unable read plugin config plugname variable: " << pluginConfigPath << std::endl;
+            std::cerr << thread_id << "Unable read plugin config plugname variable: " << pluginConfigPath << std::endl;
         }
-        syslog(LOG_ERR, "Unable read plugin config plugname variable %s", pluginConfigPath);
+        syslog(LOG_ERR, "%sUnable read plugin config plugname variable %s",thread_id.c_str(),  pluginConfigPath);
         return NULL;
     }
 
 #ifdef ENABLE_CLAMD
     if (plugname == "clamdscan") {
 #ifdef DGDEBUG
-        std::cout << "Enabling ClamDscan CS plugin" << std::endl;
+        std::cerr << thread_id << "Enabling ClamDscan CS plugin" << std::endl;
 #endif
         return clamdcreate(cv);
     }
@@ -454,7 +394,7 @@ CSPlugin *cs_plugin_load(const char *pluginConfigPath)
 #ifdef ENABLE_AVASTD
     if (plugname == "avastdscan") {
 #ifdef DGDEBUG
-        std::cout << "Enabling AvastDscan CS plugin" << std::endl;
+        std::cerr << thread_id << "Enabling AvastDscan CS plugin" << std::endl;
 #endif
         return avastdcreate(cv);
     }
@@ -463,7 +403,7 @@ CSPlugin *cs_plugin_load(const char *pluginConfigPath)
 #ifdef ENABLE_KAVD
     if (plugname == "kavdscan") {
 #ifdef DGDEBUG
-        std::cout << "Enabling KAVDscan CS plugin" << std::endl;
+        std::cerr << thread_id << "Enabling KAVDscan CS plugin" << std::endl;
 #endif
         return kavdcreate(cv);
     }
@@ -472,7 +412,7 @@ CSPlugin *cs_plugin_load(const char *pluginConfigPath)
 #ifdef ENABLE_ICAP
     if (plugname == "icapscan") {
 #ifdef DGDEBUG
-        std::cout << "Enabling ICAPscan CS plugin" << std::endl;
+        std::cerr << thread_id << "Enabling ICAPscan CS plugin" << std::endl;
 #endif
         return icapcreate(cv);
     }
@@ -481,15 +421,15 @@ CSPlugin *cs_plugin_load(const char *pluginConfigPath)
 #ifdef ENABLE_COMMANDLINE
     if (plugname == "commandlinescan") {
 #ifdef DGDEBUG
-        std::cout << "Enabling command-line CS plugin" << std::endl;
+        std::cerr << thread_id << "Enabling command-line CS plugin" << std::endl;
 #endif
         return commandlinecreate(cv);
     }
 #endif
 
     if (!is_daemonised) {
-        std::cerr << "Unable to load plugin: " << pluginConfigPath << std::endl;
+        std::cerr << thread_id << "Unable to load plugin: " << pluginConfigPath << std::endl;
     }
-    syslog(LOG_ERR, "Unable to load plugin %s\n", pluginConfigPath);
+    syslog(LOG_ERR, "%sUnable to load plugin %s\n", thread_id.c_str(), pluginConfigPath);
     return NULL;
 }
