@@ -25,9 +25,15 @@ class FDTunnel
 
     // tunnel from fdfrom to fdto
     // return false if throughput larger than target throughput (for post upload size checking)
-    bool tunnel(Socket &sockfrom, Socket &sockto, bool twoway = false, off_t targetthroughput = -1, bool ignore = false);
+    bool tunnel(Socket &sockfrom, Socket &sockto, bool twoway = false, off_t targetthroughput = -1, bool ignore = false,
+        bool chunked = false);
 
     void reset();
+
+private:
+    struct pollfd fromoutfds[1];
+    struct pollfd tooutfds[1];
+    struct pollfd twayfds[2];
 };
 
 #endif
