@@ -86,8 +86,6 @@ void FOptionContainer::reset()
 
 void FOptionContainer::resetJustListData()
 {
-    if (!(group_mode == 1))
-        return;
     if (banned_phrase_flag)
         o.lm.deRefList(banned_phrase_list);
 
@@ -251,17 +249,12 @@ bool FOptionContainer::read(const char *filename) {
         } else {
             ssl_check_cert = false;
         }
-#endif //__SSLCERT
+#endif //__SSLMITM
 
 #ifdef __SSLMITM
         if (findoptionS("sslmitm") == "on") {
             if(o.enable_ssl) {
                 ssl_mitm = true;
-                if (findoptionS("onlymitmsslgrey") == "on") {
-                    only_mitm_ssl_grey = true;
-                } else {
-                    only_mitm_ssl_grey = false;
-                }
 
                 if (findoptionS("automitm") == "off") {
                     automitm= false;
