@@ -35,9 +35,14 @@ class HTMLTemplate
     // fill in the template with the given info and send it to the client over the given socket
     // only useful if you used the default set of placeholders
     void display(Socket *s, String *url, std::string &reason, std::string &logreason, std::string &categories,
-        std::string *user, std::string *ip, std::string *host, int filtergroup, String grpname, String &hashed);
+                 std::string *user, std::string *ip, std::string *host, int filtergroup, String grpname,
+                 String &hashed);
 
-    private:
+    void display_hb(String &ebody, String *url, std::string &reason, std::string &logreason, std::string &categories,
+                    std::string *user, std::string *ip, std::string *host, int filtergroup, String grpname,
+                    String &hashed, String &localip);
+
+private:
     // add a string to the list
     void push(String s);
 };
