@@ -48,11 +48,12 @@ class HTTPHeader
 
     void setTimeout(int t);
     bool in(Socket *sock, bool allowpersistent = false );
+    bool in_handle_100(Socket *sock, bool allowpersistent = false, bool expect_100 = false );
 
     void setClientIP(String &ip);
+    String getClientIP();
 
     String stringHeader();  // output header as a String (used by ICAP)
-    String getClientIP();
 
     // send headers out over the given socket
     // "reconnect" flag gives permission to reconnect to the socket on write error
@@ -108,6 +109,7 @@ class HTTPHeader
     String searchterms();
     bool searchchecked;
     bool chunked;
+    bool expects_100 = false;
     String contentEncoding();
     String transferEncoding();
     // grab the contents of Proxy-Authorization header
@@ -154,7 +156,7 @@ class HTTPHeader
     void removeEncoding(int newlen);
     void setContentLength(int newlen);
 
-    bool DenySSL(FOptionContainer* &foc);
+    //bool DenySSL(FOptionContainer* &foc);
     // make a connection persistent - or not
     void makePersistent(bool persist = true);
     // make the request look as if its coming from the origin server
@@ -168,11 +170,7 @@ class HTTPHeader
 
     // Bypass URL & Cookie funcs
 
-    // is this a temporary filter bypass URL?
-    int isBypassURL(String url, const char *magic, const char *clientip, bool *isvirusbypass);
-    // is this a scan bypass URL? (download previously scanned file)
-    bool isScanBypassURL(String url, const char *magic, const char *clientip);
-    bool isBypassCookie(String url, const char *magic, const char *clientip);
+    bool isBypassCookie(String url, const char *magic, const char *clientip, const char *user);
     void chopBypass(String url, bool infectionbypass);
     void chopScanBypass(String url);
     // add cookie to outgoing headers with given name & value
