@@ -63,7 +63,6 @@ class LOptionContainer
 
     // access denied domain (when using the CGI)
     String access_denied_domain;
-    String sslaccess_denied_domain;
 
     void deleteFilterGroups();
     void deleteFilterGroupsJustListData();
@@ -83,7 +82,7 @@ class LOptionContainer
     bool doReadItemList(const char *filename, ListContainer *lc, const char *fname, bool swsort);
 
     // per-room blocking and URL whitelisting: see if given IP is in a room; if it is, return true and put the room name in "room"
-    bool inRoom(const std::string &ip, std::string &room, std::string *&host, bool *block, bool *part_block, bool *isexception, String url);
+    bool inRoom(const std::string &ip, std::string &room, std::string *host, bool *block, bool *part_block, bool *isexception, String url);
     void loadRooms(bool throw_error);
     void deleteRooms();
 
