@@ -32,11 +32,25 @@ public:
         Q.pop();
         return rc;
     };
-    long size() {
+    int size() {
         std::lock_guard<std::mutex> lock(d_mutex);
         return Q.size();
     }
 };
 
+struct LQ_rec {
+    Socket *sock;
+    unsigned int ct_type;
+};
+
+
+//  CT_TYPE DEFS
+#define CT_PROXY          1     // Normal proxy connection also handles tranpartent http
+#define CT_THTTPS       2     // Transparent https connection
+#define CT_ICAP              4     //  ICAP connection
+
+
+
+
 
 #endif //V4_0_QUEUE_HPP
