@@ -22,10 +22,12 @@
 #include <stdexcept>
 #include <stddef.h>
 
-#ifdef DGDEBUG
+#ifdef NETDEBUG
 #include <iostream>
 #endif
 
+extern thread_local std::string thread_id;
+
 // necessary for calculating size of sockaddr_un in a portable manner
 
 #ifndef offsetof
@@ -101,8 +103,8 @@ int UDSocket::connect(const char *path)
     if (strlen(path) > 108)
         return -1;
 
-#ifdef DGDEBUG
-    std::cout << "uds connect:" << path << std::endl;
+#ifdef NETDEBUG
+    std::cerr << thread_id << "uds connect:" << path << std::endl;
 #endif
     strcpy(my_adr.sun_path, path);
 
