@@ -25,6 +25,7 @@
 
 extern OptionContainer o;
 extern bool is_daemonised;
+extern thread_local std::string thread_id;
 
 // DECLARATIONS
 
@@ -74,7 +75,7 @@ int clamdinstance::init(void *args)
     udspath = cv["clamdudsfile"];
     if (udspath.length() < 3) {
         if (!is_daemonised)
-            std::cerr << "Error reading clamdudsfile option." << std::endl;
+            std::cerr << thread_id << "Error reading clamdudsfile option." << std::endl;
         syslog(LOG_ERR, "Error reading clamdudsfile option.");
         return DGCS_ERROR;
         // it would be far better to do a test connection to the file but
@@ -103,8 +104,7 @@ int clamdinstance::scanFile(HTTPHeader *requestheader, HTTPHeader *docheader, co
     // not usually very convenient. so instead, just allow group read on the
     // file, and tell users to make sure the daemongroup option is friendly to
     // the AV daemon's group membership.
-    // TODO? chmod can error out with EINTR, we may wish to ignore this
-    if (chmod(filename, S_IRGRP | S_IRUSR) != 0) {
+    if (chmod(filename, S_IRGRP | S_IRUSR ) != 0) {
         lastmessage = "Error giving ClamD read access to temp file";
         syslog(LOG_ERR, "Could not change file ownership to give ClamD read access: %s", strerror(errno));
         return DGCS_SCANERROR;
@@ -117,9 +117,16 @@ int clamdinstance::scanFile(HTTPHeader *requestheader, HTTPHeader *docheader, co
         command += filename;
     }
     command += "\r\n";
-#ifdef DGDEBUG
-    std::cerr << "clamdscan command:" << command << std::endl;
+#ifndef NEWDEBUG_OFF
+    if(o.myDebug->CLAMAV)
+      {
+      	std::ostringstream oss (std::ostringstream::out);
+        oss << thread_id << thread_id << "clamdscan command:" << command << std::endl;
+        o.myDebug->Debug("CLAMAV",oss.str());
+        std::cerr << thread_id << "clamdscan command:" << command << std::endl;
+       }
 #endif
+
     UDSocket stripedsocks;
     if (stripedsocks.getFD() < 0) {
         lastmessage = "Error opening socket to talk to ClamD";
@@ -140,10 +147,16 @@ int clamdinstance::scanFile(HTTPHeader *requestheader, HTTPHeader *docheader, co
         if (stripedsocks.isHup())  lastmessage += " HUPed";
         if (stripedsocks.isNoWrite())  lastmessage += " NotWritable";
         syslog(LOG_ERR, "%s", lastmessage.toCharArray());
-#ifdef DGDEBUG
-        std::cerr << lastmessage.toCharArray() <<std::endl;
+#ifndef NEWDEBUG_OFF
+    if(o.myDebug->CLAMAV)
+      {
+        std::ostringstream oss (std::ostringstream::out);
+        oss << thread_id << lastmessage.toCharArray() << std::endl;
+        o.myDebug->Debug("CLAMAV",oss.str());
+        std::cerr << thread_id << lastmessage.toCharArray() << std::endl;
+       }
 #endif
-            stripedsocks.close();
+        stripedsocks.close();
         return DGCS_SCANERROR;
     }
     char *buff = new char[4096];
@@ -157,8 +170,14 @@ int clamdinstance::scanFile(HTTPHeader *requestheader, HTTPHeader *docheader, co
         if (stripedsocks.isTimedout())  lastmessage += " TimedOut";
         if (stripedsocks.isHup())  lastmessage += " HUPed";
         if (stripedsocks.isNoRead()) lastmessage += " NotReadable";
-#ifdef DGDEBUG
-        std::cout << lastmessage.toCharArray() << std::endl;
+#ifndef NEWDEBUG_OFF
+    if(o.myDebug->CLAMAV)
+      {
+        std::ostringstream oss (std::ostringstream::out);
+        oss << thread_id << lastmessage.toCharArray() << std::endl;
+        o.myDebug->Debug("CLAMAV",oss.str());
+        std::cerr << thread_id << lastmessage.toCharArray() << std::endl;
+       }
 #endif
         syslog(LOG_ERR, "%s", lastmessage.toCharArray());
         stripedsocks.close();
@@ -167,8 +186,14 @@ int clamdinstance::scanFile(HTTPHeader *requestheader, HTTPHeader *docheader, co
     String reply(buff);
     delete[] buff;
     reply.removeWhiteSpace();
-#ifdef DGDEBUG
-    std::cout << "Got from clamdscan: " << reply << std::endl;
+#ifndef NEWDEBUG_OFF
+    if(o.myDebug->CLAMAV)
+      {
+        std::ostringstream oss (std::ostringstream::out);
+        oss << thread_id << "Got from clamdscan: " << reply << std::endl;
+        o.myDebug->Debug("CLAMAV",oss.str());
+        std::cerr << thread_id << "Got from clamdscan: " << reply << std::endl;
+       }
 #endif
     stripedsocks.close();
     if (reply.endsWith("ERROR")) {
@@ -179,12 +204,25 @@ int clamdinstance::scanFile(HTTPHeader *requestheader, HTTPHeader *docheader, co
         lastvirusname = reply.after(": ").before(" FOUND");
 // format is:
 // /foo/path/file: foovirus FOUND
-#ifdef DGDEBUG
-        std::cerr << "clamdscan INFECTED! with: " << lastvirusname << std::endl;
+
+#ifndef NEWDEBUG_OFF
+    if(o.myDebug->CLAMAV)
+      {
+        std::ostringstream oss (std::ostringstream::out);
+        oss << thread_id << "clamdscan INFECTED! with: " << lastvirusname << std::endl;
+        o.myDebug->Debug("CLAMAV",oss.str());
+        std::cerr << thread_id << "clamdscan INFECTED! with: " << lastvirusname  << std::endl;
+       }
 #endif
         if (archivewarn && (lastvirusname.contains(".Exceeded") || lastvirusname.contains(".Encrypted"))) {
-#ifdef DGDEBUG
-            std::cerr << "clamdscan: detected an ArchiveBlockMax \"virus\"; logging warning only" << std::endl;
+#ifndef NEWDEBUG_OFF
+    if(o.myDebug->CLAMAV)
+      {
+        std::ostringstream oss (std::ostringstream::out);
+        oss << thread_id << "clamdscan: detected an ArchiveBlockMax \"virus\"; logging warning only" << std::endl;
+        o.myDebug->Debug("CLAMAV",oss.str());
+        std::cerr << thread_id << "clamdscan: detected an ArchiveBlockMax \"virus\"; logging warning only" << std::endl;
+       }
 #endif
             lastmessage = "Archive not fully scanned: " + lastvirusname;
 
@@ -197,8 +235,14 @@ int clamdinstance::scanFile(HTTPHeader *requestheader, HTTPHeader *docheader, co
 // must be clean
 // Note: we should really check what the output of a "clean" message actually looks like,
 // and check explicitly for that, but the ClamD documentation is sparse on output formats.
-#ifdef DGDEBUG
-    std::cerr << "clamdscan - he say yes (clean)" << std::endl;
+#ifndef NEWDEBUG_OFF
+    if(o.myDebug->CLAMAV)
+      {
+        std::ostringstream oss (std::ostringstream::out);
+        oss << thread_id << "clamdscan - he say yes (clean)" << std::endl;
+        o.myDebug->Debug("CLAMAV",oss.str());
+        std::cerr << thread_id << "clamdscan - he say yes (clean)" << std::endl;
+       }
 #endif
     return DGCS_CLEAN;
 }
